function profile =createProfile_advanced(Image, center, radiusStart, radiusStop)

%global variable from auto3d_track that stores distances to pixels
global pixels;

%get image size and set radius of profile
[r,c]=size(Image);
searchRadius=45;

%round data to make it processable integerwise
radiusStart=floor(radiusStart);
radiusStop=ceil(radiusStop);
center=round(center);

%if starting radius is too low, make it 1
if radiusStart<=0
    radiusStart=1;
end

%if starting radius too high, make it the max
if radiusStop>=searchRadius
    radiusStop=searchRadius-1;;
end

%set boundaries of search region
left=center(1)-searchRadius;
if(left<1)
    left=1;
end

right=center(1)+searchRadius;
if(right>c)
    right=c;
end

top=center(2)-searchRadius;
if(top<1)
    top=1;
end

bottom=center(2)+searchRadius;
if(bottom>r)
    bottom=r;
end

%set center to a vector relative to this reduced region of the image
center=center-[left,top];

%get desired region of the image
Image=Image(top:bottom,left:right);

%set new values to r, c for reduced image
[r,c]=size(Image);

%find width and height of region
width=right-left+1;
height=bottom-top+1;

%create array to hold numbers to be used in profile
preprofile=zeros(2,width*height);

%create array to hold final profile
profile=zeros(2,ceil(sqrt(2)*searchRadius)+2);

%generate profile by looping through desired radii
for rad=radiusStart:radiusStop
    
    %go through pixels array created in auto3d_track and use defined pixel
    %numbers to determine which pixels should be observed.  pixels holds
    %indices in a 2D array, where row radius+1 has the format:
    %[number of pixels for this radius, c_value1, r_value1, ...]
    for index=2:2:pixels(rad+1,1)
        %look at r and c and check to see if within observation boundary
        r_check=center(2)+pixels(rad+1,index+1);
        c_check=center(1)+pixels(rad+1,index);
        
        if(r_check<1 || r_check>r || c_check<1 || c_check>c)
            continue;
        end
        
        %add this value to the profile, and add one to the number of pixels
        %at this value.  This second number is used for averaging
        profile(1,rad)=profile(1,rad)+Image(r_check,c_check);
        profile(2,rad)=profile(2,rad)+1;
    end
end

%average the profile
profile(2,find(profile(1,:)==0))=1;
profile=profile(1,:)./profile(2,:);

%ensure that minimum of profile is 0
profile=profile-min(profile);