% close all;

%threshold under which two tracks may be linked if they are similar enough
%in time
dis_threshold=8;

%this is the maximum number of frames between the end of one track and the
%start of another that will still allow for track linking
max_dt=4;

n_track=length(tk);

%find the values of relevant track properties both at their first and their
%last time step
for i=1:n_track
    np=tk(i).np;
    t1s(i)=tk(i).t(1);
    tns(i)=tk(i).t(np);    
    x1s(i)=tk(i).x(1);
    xns(i)=tk(i).x(np);
    y1s(i)=tk(i).y(1);
    yns(i)=tk(i).y(np);  
    z1s(i)=tk(i).z(1);
    zns(i)=tk(i).z(np);
    tk(i).merged=0;
    tk(i).next=-1;
end

nmerged=0;

%loop through all tracks
for i=1:n_track
    
    %find delta t between start of every track and end of this track
    dt=t1s-tns(i);
    
    %set a flag for each of the tracks in which this delta t is less than
    %or equal to four frames and greater than or equal to 2 frames
    flag=(dt<=max_dt).*(dt>=2);
    
    %find where the flags are 1, and if none are one just keep going
    I=find( flag==1 );
    if isempty(I)
        continue;
    end
    
    %find the distances between the start of all tracks with flags 1 and
    %the end of this track
    dis=sqrt((x1s(I)-xns(i)).^2+(y1s(I)-yns(i)).^2+(z1s(I)-zns(i)).^2);
    
    %find the minimum of these distances
    [mindis, J]=min(dis);
    
    %if the minimum of these distances is less than the threshold, merge
    %these tracks
    if(mindis<dis_threshold)
        tk(i).next=I(J);
        tk(I(J)).merged=1;
        nmerged=nmerged+1;
    end
end
nmerged

ncnt=0;

%run through all tracks again
for i=1:n_track
    
    %if this track was merged ignore it, it is now part of another track
    if(tk(i).merged==1)
        continue;
    end
    
    %if this track was not merged and does not have another track as it's
    %'next' track (ie nothing was merged to it) put it in tk2
    if tk(i).next==-1
        ncnt=ncnt+1;
        tk2(ncnt)=tk(i);
    else
        %while tracks are still being merged, run through them merging them
        while(tk(i).next>0)
            J=tk(i).next;
            np=tk(i).np;
            
            %concatanate these tracks into their base track
            tk(i).np=tk(i).np+tk(J).np;
            tk(i).next=tk(J).next;
            tk(i).x=[tk(i).x tk(J).x];
            tk(i).y=[tk(i).y tk(J).y];
            tk(i).z=[tk(i).z tk(J).z];
            tk(i).t=[tk(i).t tk(J).t];
            tk(i).dx=[tk(i).dx tk(J).dx];
            tk(i).dy=[tk(i).dy tk(J).dy];
        end           
        ncnt=ncnt+1;
        
        %put these concatanated tracks into tk2
        tk2(ncnt)=tk(i);
    end       
end
ncnt


%output results
figure
cmp=colormap('jet');
hold on;
nn=0;
for i=1:ncnt
    if(tk2(i).np<6)
        continue;
    end
    cind=floor(rand(1,1)*63)+1;
    plot3(tk2(i).x, tk2(i).y, tk2(i).z,'color', cmp(cind,:));
    nn=nn+1;
end
nn

save final_tracks tk2;